<?php
/**
 * Transfer
 *
 * @package GamiPress\Transfers\Notes\Transfer
 * @since 1.0.0
 */
// Exit if accessed directly
if( !defined( 'ABSPATH' ) ) exit;

/**
 * Add "Notes" field on shortcodes
 *
 * @since 1.0.0
 *
 * @param array $fields
 *
 * @return array
 */
function gamipress_transfers_notes_transfer_shortcode_fields( $fields ) {

    $fields['notes'] = array(
        'name'        => __( 'Notes', 'gamipress-transfers-notes' ),
        'description' => __( 'Allow user to introduce notes on this transfer.', 'gamipress-transfers-notes' ),
        'type' 	      => 'checkbox',
        'classes' => 'gamipress-switch',
    );

    return $fields;
}
// [gamipress_points_transfer] fields
add_filter( 'gamipress_gamipress_points_transfer_shortcode_fields', 'gamipress_transfers_notes_transfer_shortcode_fields' );
// [gamipress_achievement_transfer] fields
add_filter( 'gamipress_gamipress_achievement_transfer_shortcode_fields', 'gamipress_transfers_notes_transfer_shortcode_fields' );
// [gamipress_rank_transfer] fields
add_filter( 'gamipress_gamipress_rank_transfer_shortcode_fields', 'gamipress_transfers_notes_transfer_shortcode_fields' );

/**
 * Add "Notes" field  on shortcodes tabs
 *
 * @since 1.0.0
 *
 * @param array $tabs
 *
 * @return array
 */
function gamipress_transfers_notes_transfer_shortcode_tabs( $tabs ) {

    $tabs['form']['fields'][] = 'notes';

    return $tabs;
}
// [gamipress_points_transfer] tabs
add_filter( 'gamipress_gamipress_points_transfer_shortcode_tabs', 'gamipress_transfers_notes_transfer_shortcode_tabs' );
// [gamipress_achievement_transfer] tabs
add_filter( 'gamipress_gamipress_achievement_transfer_shortcode_tabs', 'gamipress_transfers_notes_transfer_shortcode_tabs' );
// [gamipress_rank_transfer] tabs
add_filter( 'gamipress_gamipress_rank_transfer_shortcode_tabs', 'gamipress_transfers_notes_transfer_shortcode_tabs' );

/**
 * Add "Notes" field on shortcodes defaults attributes (by default "no")
 *
 * @since 1.0.0
 *
 * @param array $shortcode_defaults
 *
 * @return array
 */
function gamipress_transfers_notes_transfer_shortcode_defaults( $shortcode_defaults ) {

    $shortcode_defaults['notes'] = 'no';

    return $shortcode_defaults;
}
// [gamipress_points_transfer] defaults
add_filter( 'gamipress_points_transfer_shortcode_defaults', 'gamipress_transfers_notes_transfer_shortcode_defaults' );
// [gamipress_achievement_transfer] defaults
add_filter( 'gamipress_achievement_transfer_shortcode_defaults', 'gamipress_transfers_notes_transfer_shortcode_defaults' );
// [gamipress_rank_transfer] defaults
add_filter( 'gamipress_rank_transfer_shortcode_defaults', 'gamipress_transfers_notes_transfer_shortcode_defaults' );

/**
 * Common function to render notes field on transfer form
 *
 * @since 1.0.0
 *
 * @param array       $template_args    Template received arguments
 */
function gamipress_transfer_notes_transfer_template( $template_args ) {

    // Shorthand
    $a = $template_args;

    if( ! isset( $a['notes'] ) )
        $a['notes'] =  'no';

    if( $a['notes'] === 'yes' ) :
        /**
         * Filters the notes field label on transfer form template
         *
         * @since 1.0.0
         *
         * @param string    $notes_label    Notes field label, by default "Notes:"
         * @param array     $template_args  Template received arguments
         *
         * @return string
         */
        $notes_label = apply_filters( 'gamipress_transfer_notes_transfer_form_notes_label', __( 'Notes:', 'gamipress-transfers-notes' ), $a ); ?>

        <fieldset class="gamipress-transfers-notes-transfer-form-notes">

            <p id="<?php echo $a['form_id']; ?>-notes" class="gamipress-transfers-notes-transfer-form-notes-input">

                <label for="<?php echo $a['form_id']; ?>-notes"><?php echo $notes_label; ?></label>

                <textarea
                    id="<?php echo $a['form_id']; ?>-notes-input"
                    class="gamipress-transfers-notes-transfer-form-notes-input"
                    name="<?php echo $a['form_id']; ?>-notes"
                    type="text"
                ></textarea>

            </p>

        </fieldset>

    <?php endif;


}

/**
 * Before render points transfer form total
 *
 * @since 1.0.0
 *
 * @param integer     $user_id          User ID
 * @param integer     $recipient_id     Recipient ID (if is set)
 * @param integer     $amount           Amount to be transfer
 * @param integer     $user_points      User earned points
 * @param string      $points_type      Points type
 * @param array       $template_args    Template received arguments
 */
function gamipress_transfers_notes_points_transfer_template( $user_id, $recipient_id, $amount, $user_points, $points_type, $template_args ) {
    gamipress_transfer_notes_transfer_template( $template_args );
}
add_action( 'gamipress_transfers_before_points_transfer_form_total', 'gamipress_transfers_notes_points_transfer_template', 10, 6 );

/**
 * Before render achievement/rank transfer form submit
 *
 * @since 1.1.3
 *
 * @param integer     $user_id          User ID
 * @param integer     $recipient_id     Recipient ID (if is set)
 * @param integer     $post_id          Achievement/Rank ID (if is set)
 * @param array       $template_args    Template received arguments
 */
function gamipress_transfers_notes_achievement_rank_transfer_template( $user_id, $recipient_id, $post_id, $template_args ) {
    gamipress_transfer_notes_transfer_template( $template_args );
}
add_action( 'gamipress_transfers_before_rank_transfer_form_submit', 'gamipress_transfers_notes_achievement_rank_transfer_template', 10, 4 );

/**
 * Process the transfer and get their response
 *
 * @since 1.0.0
 *
 * @param array     $response       Processing response
 * @param array     $transfer       Transfer data array
 * @param array     $transfer_items Transfer items array
 *
 * @return array    $response       Response
 */
function gamipress_transfers_notes_process_transfer_response( $response, $transfer, $transfer_items ) {

    $prefix = '_gamipress_transfers_notes_';

    // Check transfer form parameters
    $transfer_key = isset( $_POST['transfer_key'] ) ? $_POST['transfer_key'] : '';
    $form_id = 'gamipress-transfers-transfer-form-' . $transfer_key;

    // Get notes field
    $notes = isset( $_POST[$form_id . '-notes'] ) ? $_POST[$form_id . '-notes'] : '';

    // Sanitize
    $notes = sanitize_textarea_field( $notes );

    // Save the notes on the transfer
    ct_setup_table( 'gamipress_transfers' );

    ct_update_object_meta( $transfer['transfer_id'], $prefix . 'notes', $notes );

    ct_reset_setup_table();

    return $response;

}
add_filter( 'gamipress_transfers_process_transfer_response', 'gamipress_transfers_notes_process_transfer_response', 10, 3 );